@@ -6,7 +6,7 @@ use warnings FATAL => 'all';
 
 use Exporter 'import';
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 
 our @EXPORT_OK   = qw(exists_one_of  list_exists  num_exists
@@ -64,7 +64,7 @@ Hash::Util::Exists::Tiny - Some hash helper functions related to perl's exists f
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 
 =head1 SYNOPSIS
@@ -161,14 +161,14 @@ You can also look for information at:
 
 L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Hash-Util-Exists-Tiny>
 
-=item * CPAN Ratings
-
-L<https://cpanratings.perl.org/d/Hash-Util-Exists-Tiny>
-
 =item * Search CPAN
 
 L<https://metacpan.org/release/Hash-Util-Exists-Tiny>
 
+=item * GitHub Repository
+
+L<https://github.com/AAHAZRED/perl-Hash-Util-Exists-Tiny.git>
+
 =back
 
 
